#
# spec file for package smenu
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           smenu
Version:        0.9.15
Release:        bp153.1.16
Summary:        A standard input word picker
License:        GPL-2.0-only
Group:          Productivity/Text/Utilities
Url:            https://github.com/p-gen/%{name}
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  ncurses-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This tool reads words from a file or standard input, presents them in an
interactive window after the current line on the terminal, and writes the
selected words, if any, to standard output.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%package tests
Summary:        Testing system for %{name}
Group:          Productivity/Text/Utilities

%description tests
This packages contains some scripts and a number of tests to check the
%{name} tool.

%install
%if 0%{?suse_version} < 1315
make install DESTDIR="%{?buildroot}"
%else
%make_install
%endif

%files tests
%defattr(-,root,root,-)
%doc tests

%files
%defattr(-,root,root,-)
%attr(0755,root,root) %{_bindir}/*
%if 0%{?sle_version} < 120300 && 0%{?suse_version} <= 1315
%doc COPYRIGHT
%else
%license COPYRIGHT
%endif
%doc examples README.rst FAQ
%{_mandir}/man1/*

%changelog
* Sat Mar 30 2019 Pierre Gentile <p.gen.progs@gmail.com>
- Version 0.9.15
  * Bug fixes:
  + An ending pattern search was not correctly highlighted
  + An highlighting issue when hitting the HOME key during a search
    in numbered mode has been fixed
  + The PgUp/PgDn moves have been fixed and improved in the presence of
    excluded words
  + The height of the windows when a message is present is now correctly
    calculated
  + The SIGINT signal handling is working properly now
  + A vt100 terminal is assumed when the environment variable TERM
    is unset
  * Improvements:
  + The 'o' sub-option of the -D option has been enhanced
  + The documentation has been improved and enhanced
  + An example of a hierarchical menu interpreter has been added
  + The message (title) appearance can now be changed with the -a option
  + An empty line has been added after the message (title) for clarity
  + The .spec file has been updated to support older SUSE/RH versions
  + An issue opening /dev/tty is now clearly signaled
  + The argument of the -n option is now optional and defaults to 0
    (full height)
  + It is now possible to directly move the cursor to the start/end of
    the current line
  * Misc:
  + The code has been split into several files
  + The pull request #15 from sumbach/patch-1 has been merged
  + The pull request #12 from jonnydubowsky/patch-1 has been merged
  + More tests for the automatic regressions checking have been added
  + UTF-8 string length processing has been optimized
  + Help and usage messages are now printed on stdout
  + A FAQ has been added
  + Compiler warnings have been silenced
* Tue Sep 18 2018 Ismail Dönmez <idonmez@suse.com>
- Use %%license for COPYRIGHT
- Run spec-cleaner
* Thu Sep 13 2018 p.gen.progs@gmail.com
- Delete forgotten debug files in the 'examples' directory
- Fix some rpmlint warnings and errors
* Wed Sep 12 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and history lesson from description.
* Tue Sep  4 2018 p.gen.progs@gmail.com
- Version 0.9.14
  * Rework the search system (major change)
  + Add a substring and a fuzzy (fzf inspired) search mode
  + Enlighten the current search pattern in the matching words
  + Remove the search mode timeout
  + Introduce ENTER/ESC as a way to exit search mode
  + Add the prefix/suffix affinity when searching
  + Allow to tag/un-tag all the matching words
  + add a -/ option to affect a search method to the / command
  + Add 'T' and 'U' commands to tag/un-tag all the matching words
  * Improve the direct access mechanism
  + [-D] Add a 's' (start) sub-option
  + [-D] Add a 'h' (head) sub-option
  * Add a "full window" option value to -n
  * Improve the test system and add tests
  * Improve the documentation
  * Update the README.rst file and mention the wiki on GitHub
  * Fix an OpenBSD compatibility issue
  * Fix and improve the color mechanism
  * Fix the cursor display after an ESC hit
  * Fix the tag attribute display
  * Fix some compilation warnings
  * Fix a missing message when the terminal is too small
  * Fix a lot of other small and not-so-small bugs
* Tue May 22 2018 p.gen.progs@gmail.com
- Version 0.9.13
  * Add the first roll of an automated testing system
  * Add the subpackage '-tests' in the specfile
  * Fix a FreeBSD compatibility issue
  * [-a] Add a missing setting for cursor_on_tag (ct)
  * [-b] Fix a bug about non-printable characters
  * [-V] Output version on standard output
  * [-D] Add a 'decorate' directive
  * [-D] Handle multiple instances of the same directive
  * Fix a logic error in the direct access code
  * Fix an horizontal scrolling issue when going to the last word
  * Clean up the allocated gutter array before leaving in case of error
  * Add some more terminfo sequences
  * Fix the right margin and add a degraded method to display it
  * Improve the manual
  * Various other small bug fixes
* Sun Apr  8 2018 p.gen.progs@gmail.com
- Version 0.9.12
  * Fix the cursor restoration
  * Fix a Solaris incompatibility
  * Fix italic handling
  * Fix the replacement of subexpressions (-S,-I,-E)
  * Fix a bug in the columns inclusion logic
  * Fix the impossibility to use the letter 't' in search mode
  * Fix possible display errors when the terminal is resized
  * Make sure that the timers does not alter the redrawing of the window
  * Add word numbering to allow direct access through their number (-N,-U,-F,-D)
  * Improve The manual
  * Allow the \u notation for UTF-8 characters in more places
  * Improve the -T option and add the related -P option
  * Add the -p for use with the -P and -T options
  * The gutter option (-g) now accepts a parameter
  * Adopt the NO_COLOR standard (http://no-color.org)
  * Improve the navigation by understanding more keys and key combinations
  * Understand CTRL+L to redraws the window in case of corruption
  * Exit from search mode when a direction key is hit
  * Adjust some values of timers
  * Remove deprecated directives in -C and -L
  * Various other small fixes and improvements
* Fri Jan 26 2018 p.gen.progs@gmail.com
- Version 0.9.11
  * Introduce the new \u notation for UTF-8 hex sequences
  * Non-printable characters with an escape form are expanded
  * Keep non selectable blank words to allow special effects
  * Fix the wide option when in column or tabulation mode
  * The last word is always the last of its line (-g)
  * Improve message (-m) placement in centered mode
  * Manage substitutions leading to empty strings
  * Hopefully fix the placement of the scroll bar in all cases
  * The gutter can now be displayed in column mode
  * Various other small fixes
* Wed Dec 13 2017 p.gen.progs@gmail.com
- Version 0.9.10
  * The words acquisition is rewritten and splitted in multiple phases
  * Add the capacity to (de)select rows an columns containing regexes
  * -i, -e, -C and -R can be used more than once and have a cumulative effect
  * Bugfix: -s is able to jump to non selectable words
  * Bugfix: The attributes are not overloaded when reading configuration files
  * Bugfix: the right bar is too far right in some cases.
  * Bugfix: the right shift indicator is omitted in some cases
  * Add a -x|-X option to set a timeout in seconds
  * Add a -f option to select an alternative configuration file
  * Add a -a option to set the attributes of the displayed elements
  * Add more controls in the selection parser
  * smenu can now read words directly from a file given as parameter
  * Rewrite the replace function used by -S/-I/-E with a more sed-like one
  * Searches should always consider the visual aspect of words (-S/-I/-E)
* Thu Dec 22 2016 p.gen.progs@gmail.com
- Version 0.9.9
  * New UTF8 validation routine
  * Man page cleanup
  * Code cleanup and improvement
  * Improved configuration process
  * Add code to detect the host system at compile time
  * Compilation is now possible on BSD system derivatives
  * Bug fix: ignore EOF when a scancode contains an escape sequence.
  * Fix the cursor appearance on tagged words
* Sun Dec 11 2016 p.gen.progs@gmail.com
- Version 0.9.8
  * Change the cursor aspect when the selected word is tagged
  * Add a small animated gif demo
  * Fix a potential infinite loop
  * Use custom fgetc/ungetc to be able to safely push back more than one byte
  * Add libtinfo in the searched libraries an regenerate configure
  * Manage conflicts between -C, -R, -c, -l, and -t
  * Improve and fix the help line display
  * Add a -T option to enable a tagging (multi-selections) mode
  * Add the -? option to only display the synopsys
  * Adjust the code so that it can be compiled with an ansi compiler
  * Put the searched line in the middle of the displayed window if possible
  * Add a -k option to prevent trimming spaces
  * Fix the -s option
  * When not in search mode, any key except '?' should quit the help mode
  * Add a new example: yesno
  * Fix an off-by-one error when using -c and -w together
  * And many other minor changes and fixes
* Sun Mar 13 2016 p.gen.progs@gmail.com
- Version 0.9.1
  * Use the GNU autotools
  * Fix a lot of small and not so small bugs
  * Change the -s option semantic
  * Improve help and man page
  * Introduce some new options - see the man page for more
  * Also rework some options - see the man page for more
  * Add more configurable colors
  * Add the notion of non-selectable words
  * Add the notion of special words
  * Add a (de)selection by rows and/or columns
  * Interpret quotations in the input stream and ignore empty words
  * Add an option to center the output window
  * And many other minor changes
* Sun Aug  9 2015 p.gen.progs@gmail.com
- Initial version - 0.9
